Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(551)

Unified Diff: storage/browser/fileapi/file_system_context.h

Issue 2890143004: Rename TaskRunner::RunsTasksOnCurrentThread() in //storage (Closed)
Patch Set: for Requirements Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « storage/browser/database/database_quota_client.cc ('k') | storage/browser/fileapi/file_system_context.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: storage/browser/fileapi/file_system_context.h
diff --git a/storage/browser/fileapi/file_system_context.h b/storage/browser/fileapi/file_system_context.h
index 93a4825e0aa8fc38fb5747ae594ba859690474c1..c7190f2de54ac402fda8925c36359511c7ee29c2 100644
--- a/storage/browser/fileapi/file_system_context.h
+++ b/storage/browser/fileapi/file_system_context.h
@@ -94,8 +94,8 @@ class STORAGE_EXPORT FileSystemContext
// file_task_runner is used as default TaskRunner.
// Unless a FileSystemBackend is overridden in CreateFileSystemOperation,
// it is used for all file operations and file related meta operations.
// The code assumes that file_task_runner->RunsTasksOnCurrentThread()
// returns false if the current task is not running on the thread that allows
// blocking file operations (like SequencedWorkerPool implementation does).
//
// |external_mount_points| contains non-system external mount points available
@@ -321,7 +321,7 @@ class STORAGE_EXPORT FileSystemContext
DefaultContextDeleter>;
~FileSystemContext();
- void DeleteOnCorrectThread() const;
+ void DeleteOnCorrectSequence() const;
// Creates a new FileSystemOperation instance by getting an appropriate
// FileSystemBackend for |url| and calling the backend's corresponding
@@ -409,7 +409,7 @@ class STORAGE_EXPORT FileSystemContext
struct DefaultContextDeleter {
static void Destruct(const FileSystemContext* context) {
- context->DeleteOnCorrectThread();
+ context->DeleteOnCorrectSequence();
}
};
« no previous file with comments | « storage/browser/database/database_quota_client.cc ('k') | storage/browser/fileapi/file_system_context.cc » ('j') | no next file with comments »
@@ -94,8 +94,8 @@ class STORAGE_EXPORT FileSystemContext
// Unless a FileSystemBackend is overridden in CreateFileSystemOperation,
// it is used for all file operations and file related meta operations.
- // The code assumes that file_task_runner->RunsTasksOnCurrentThread()
- // returns false if the current task is not running on the thread that allows
+ // The code assumes that file_task_runner->RunsTasksInCurrentSequence()
+ // returns false if the current task is not running on the sequence that allows
// blocking file operations (like SequencedWorkerPool implementation does).
//

Powered by Google App Engine
This is Rietveld 408576698